@@ -314,6 +314,9 @@ extern int fut_getbuffer( int *nints, unsigned long **buffer, unsigned long *nex
 
 extern int fut_header( unsigned long head, ... );
 
+extern void enable_fut_flush( void );
+extern void disable_fut_flush( void );
+
 /* activate the recording of thread id */
 extern void fut_enable_tid_logging();
 
